summaryrefslogtreecommitdiffstats
path: root/kdm/kfrontend/themer/kdmitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdm/kfrontend/themer/kdmitem.h')
-rw-r--r--kdm/kfrontend/themer/kdmitem.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdm/kfrontend/themer/kdmitem.h b/kdm/kfrontend/themer/kdmitem.h
index 230ed71c4..31d4fcfa2 100644
--- a/kdm/kfrontend/themer/kdmitem.h
+++ b/kdm/kfrontend/themer/kdmitem.h
@@ -96,7 +96,7 @@ public:
/**
* Fixup the geometry of an item and its children (even if fixed
- * or boxed ones). Note that this will generate repaint signals
+ * or boxed ones). Note that this will generate tqrepaint signals
* when needed. The default implementation should fit all needs.
*/
virtual void setGeometry( const TQRect &newGeometry, bool force );
@@ -109,7 +109,7 @@ public:
void paint( TQPainter *painter, const TQRect &boundaries );
/**
- * Update representation of contents and repaint.
+ * Update representation of contents and tqrepaint.
*/
virtual void update();
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
* Similar to sizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.
* @param parentGeometry the geometry of the caller item or a
@@ -147,7 +147,7 @@ public:
TQString baseDir() const
{
if (basedir.isEmpty() && parent())
- return static_cast<KdmItem *>( parent()->qt_cast( "KdmItem" ) )->baseDir();
+ return static_cast<KdmItem *>( tqparent()->tqqt_cast( "KdmItem" ) )->baseDir();
return basedir;
}
@@ -163,7 +163,7 @@ public:
bool isExplicitlyHidden() const { return isShown == ExplicitlyHidden; }
TQRect rect() const { return area; }
- TQWidget *parentWidget() const;
+ TQWidget *tqparentWidget() const;
TQString getId() const { return id; }
signals:
@@ -181,7 +181,7 @@ protected:
* @return (-1,-1) if no size can be determined (so it should
* default to parent's size).
*/
- virtual TQSize sizeHint();
+ virtual TQSize tqsizeHint();
/**
* Low level graphical function to paint the item.
@@ -195,7 +195,7 @@ protected:
/**
* Called when item changes its 'state' variable. This must
- * handle item's repaint.
+ * handle item's tqrepaint.
*/
virtual void statusChanged();
@@ -120,7 +120,7 @@ public:
void mouseEvent( int x, int y, bool pressed = false, bool released = false );
/**
- * Similar to sizeHint(..), this returns the area of the item
+ * Similar to tqsizeHint(..), this returns the area of the item
* given the @p parentGeometry. The default implementation
* takes into account geometric constraints and layoutings.